ScopedClosure

Struct ScopedClosure 

pub struct ScopedClosure<'a, T: ?Sized> { /* private fields */ }
Borrowed or owned closure handle for passing Rust closures to JavaScript.

Implementations

Source

impl<'a, T> ScopedClosure<'a, T>
where T: ?Sized + WasmClosure,

pub fn as_js_value(&self) -> &JsValue

Returns the JavaScript function value for this closure.

Source

impl<T> ScopedClosure<'static, T>
where T: ?Sized + WasmClosure,

pub fn new<F>(t: F) -> Self
where F: IntoWasmClosure<T> + MaybeUnwindSafe + 'static,

pub fn own<F>(t: F) -> Self
where F: IntoWasmClosure<T> + MaybeUnwindSafe + 'static,

pub fn own_aborting<F>(t: F) -> Self
where F: IntoWasmClosure<T> + 'static,

pub fn own_assert_unwind_safe<F>(t: F) -> Self
where F: IntoWasmClosure<T> + 'static,

pub fn wrap<F>(data: Box<F>) -> Self
where F: IntoWasmClosure<T> + ?Sized + MaybeUnwindSafe,

pub fn wrap_aborting<F>(data: Box<F>) -> Self
where F: IntoWasmClosure<T> + ?Sized,

pub fn wrap_assert_unwind_safe<F>(data: Box<F>) -> Self
where F: IntoWasmClosure<T> + ?Sized,

pub fn borrow<'a, F>(t: &'a F) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRef<T> + MaybeUnwindSafe + ?Sized,

pub fn borrow_aborting<'a, F>(t: &'a F) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRef<T> + ?Sized,

pub fn borrow_assert_unwind_safe<'a, F>( t: &'a F, ) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRef<T> + ?Sized,

pub fn borrow_mut<'a, F>(t: &'a mut F) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRefMut<T> + MaybeUnwindSafe + ?Sized,

pub fn borrow_mut_aborting<'a, F>(t: &'a mut F) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRefMut<T> + ?Sized,

pub fn borrow_mut_assert_unwind_safe<'a, F>( t: &'a mut F, ) -> ScopedClosure<'a, T::Static>
where F: IntoWasmClosureRefMut<T> + ?Sized,

pub fn once<F, A, R>(fn_once: F) -> Self
where F: WasmClosureFnOnce<T, A, R> + MaybeUnwindSafe,

Create a Closure from a function that can only be called once.

Since we have no way of enforcing that JS cannot attempt to call this FnOnce more than once, this produces a Closure<dyn FnMut(A...) -> R> that will panic if called more than once.

pub fn once_aborting<F, A, R>(fn_once: F) -> Self
where F: WasmClosureFnOnceAbort<T, A, R>,

pub fn once_assert_unwind_safe<F, A, R>(fn_once: F) -> Self
where F: WasmClosureFnOnceAbort<T, A, R>,

pub fn forget(self)

Forgets the closure, leaking it.

pub fn into_js_value(self) -> JsValue

Converts the Closure into a JsValue.

pub fn once_into_js<F, A, R>(fn_once: F) -> JsValue
where F: WasmClosureFnOnce<T, A, R> + MaybeUnwindSafe,

Create a Closure from a function that can only be called once, and return the underlying JsValue directly.

This is a convenience method that combines once and into_js_value.