pub unsafe trait ErasableGeneric {
type Repr: 'static;
}Expand description
Marker for types whose generic parameters erase to one stable runtime representation.
Safety
Implementors must have the same runtime representation as Repr.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".